@@ -1,6 +1,7 @@
 from oneparams.api.base_diff import BaseDiff
 from oneparams.api.conta import ApiConta
 from oneparams.api.operadora import Operadora
+from oneparams.utils import deemphasize
 
 
 class ApiCard(BaseDiff):
@@ -21,6 +22,12 @@ class ApiCard(BaseDiff):
                          submodules={
                              "contasId": ApiConta(),
                              "operadoraCartaoId": Operadora()
+                         },
+                         handle_errors={
+                             "API.CARTOES.DELETE.REFERENCE":
+                             "Cant delete card...",
+                             "API.OCARTAO.CARTAODETALHES.FORNECEDOR.NOTFOUND":
+                             "ERROR! Card Operator does not have a supplier"
                          })
 
         if not ApiCard.first_get:
@@ -44,8 +51,11 @@ class ApiCard(BaseDiff):
         return id
 
     def item_id(self, data):
-        for key, item in ApiCard.items.items():
-            if (item["descricao"] == data["descricao"]
+        name = deemphasize(data[self.key_name])
+        for key, item in self.items.items():
+            item_normalized = deemphasize(item[self.key_name])
+            if (item_normalized == name
                     and item["debito_Credito"] == data["debito_Credito"]):
                 return key
         return 0
+
