@@ -1,5 +1,3 @@
-import json
-
 from oneparams.api.base_diff import BaseDiff
 from oneparams.api.perfils import Perfil
 from oneparams.api.profissao import Profissao
@@ -55,11 +53,6 @@ class ApiColaboradores(BaseDiff):
         self.items[id] = data
         return id
 
-    def get_sheduler(self):
-        response = self.get("/OProfissional/ProfissionaisAgendaveis")
-        self.status_ok(response)
-        return json.loads(response.content)
-
     def equals(self, data: dict) -> bool:
         if data["email"] is None:
             data.pop("email")
@@ -83,11 +76,11 @@ class ApiColaboradores(BaseDiff):
 
     def item_id(self, data: dict) -> int:
         name = deemphasize(data[self.key_name])
-        email = deemphasize(data["email"])
+        email = deemphasize(data["email"]).strip()
 
         for key, item in self.items.items():
             existent_name = deemphasize(item[self.key_name])
-            existent_email = deemphasize(item["email"])
+            existent_email = deemphasize(item["email"]).strip()
 
             if (existent_name == name
                     or existent_email == email):
